@@ -138,8 +138,8 @@ if( defined $opt_version ) {
 }
 
 # At least 1 term should be given on the command line.
-if(scalar(@ARGV) < 1) {
-    print STDERR "No term was specified on the command line\n";
+if(scalar(@ARGV) <= 1) {
+    print STDERR "A term and relation must be specified\n";
     &minimalUsageNotes();
     exit;
 }
@@ -152,42 +152,37 @@ my $socket   = "/tmp/mysql.sock";
 if(defined $opt_socket)   { $socket   = $opt_socket;   }
 
 my $umls = "";
+my %option_hash = ();
 
-if(defined $opt_username and defined $opt_password and defined $opt_config) {
-    $umls = UMLS::Interface->new({"driver" => "mysql", 
-				  "database" => "$database", 
-				  "username" => "$opt_username",  
-				  "password" => "$opt_password", 
-				  "hostname" => "$hostname", 
-				  "socket"   => "$socket",
-			          "config"   => "$opt_config"}); 
-    die "Unable to create UMLS::Interface object.\n" if(!$umls);
-    ($errCode, $errString) = $umls->getError();
-    die "$errString\n" if($errCode);
+if(defined $opt_config) {
+    $option_hash{"config"} = $opt_config;
 }
-elsif(defined $opt_username and defined $opt_password) {
-    $umls = UMLS::Interface->new({"driver" => "mysql", 
-				  "database" => "$database", 
-				  "username" => "$opt_username",  
-				  "password" => "$opt_password", 
-				  "hostname" => "$hostname", 
-				  "socket"   => "$socket"}); 
-    die "Unable to create UMLS::Interface object.\n" if(!$umls);
-    ($errCode, $errString) = $umls->getError();
-    die "$errString\n" if($errCode);
+if(defined $opt_verbose) {
+    $option_hash{"verbose"} = $opt_verbose;
 }
-elsif(defined $opt_config) {
-    $umls = UMLS::Interface->new({"config" => "$opt_config"});
-    die "Unable to create UMLS::Interface object.\n" if(!$umls);
-    ($errCode, $errString) = $umls->getError();
-    die "$errString\n" if($errCode);
+if(defined $opt_username) {
+    $option_hash{"username"} = $opt_username;
 }
-else {
-    $umls = UMLS::Interface->new(); 
-    die "Unable to create UMLS::Interface object.\n" if(!$umls);
-    ($errCode, $errString) = $umls->getError();
-    die "$errString\n" if($errCode);
+if(defined $opt_driver) {
+    $option_hash{"driver"}   = "mysql";
 }
+if(defined $opt_database) {
+    $option_hash{"database"} = $database;
+}
+if(defined $opt_password) {
+    $option_hash{"password"} = $opt_password;
+}
+if(defined $opt_hostname) {
+    $option_hash{"hostname"} = $hostname;
+}
+if(defined $opt_socket) {
+    $option_hash{"socket"}   = $socket;
+}
+
+$umls = UMLS::Interface->new(\%option_hash); 
+die "Unable to create UMLS::Interface object.\n" if(!$umls);
+($errCode, $errString) = $umls->getError();
+die "$errString\n" if($errCode);
 
 &errorCheck($umls);
 
@@ -214,6 +209,9 @@ foreach my $cui (@c) {
 	print STDERR "ERROR: The concept ($cui) is not valid.\n";
 	exit;
     }
+
+    #  make certain cui exists in this view
+    if($umls->checkConceptExists($cui) == 0) { next; }	
     
     my @cuis = $umls->getRelated($cui, $rel); 
     
@@ -290,7 +288,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: getRelated.pl,v 1.1.1.1 2009/10/14 15:38:57 btmcinnes Exp $';
+    print '$Id: getRelated.pl,v 1.6 2010/01/07 23:15:44 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
